import matplotlib.pyplot as plt 

def plot01(img1):
    plt.figure(figsize=(5,5))   #/
    plt.axis('off')
    plt.imshow(img1)
    plt.show()
def plot02(img1,img2):
    plt.figure(figsize=(8,4))   #/
    plt.subplot(121)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(122)
    plt.axis('off')
    plt.imshow(img2)
    plt.show()
def plot03(img1,img2,img3):
    plt.figure(figsize=(35,17))  #/
    plt.subplot(131)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(132)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(133)
    plt.axis('off')
    plt.imshow(img3)
    plt.show()
def plot04(img1,img2,img3,img4):
    plt.figure(figsize=(13,15))       #/
    plt.subplot(141)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(142)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(143)
    plt.axis('off')
    plt.imshow(img3)
    plt.subplot(144)
    plt.axis('off')
    plt.imshow(img4)
    plt.show()
def plot05(img1,img2,img3,img4,img5):
    plt.figure(figsize=(13,5))       #/
    plt.subplot(151)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(152)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(153)
    plt.axis('off')
    plt.imshow(img3)
    plt.subplot(154)
    plt.axis('off')
    plt.imshow(img4)
    plt.subplot(155)
    plt.axis('off')
    plt.imshow(img5)
    plt.show()
def plot06(img1,img2,img3,img4,img5,img6):
    # plt.figure(figsize=(39, 25)) #//
    plt.figure(figsize=(35,17)) #//
    plt.subplot(241)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(242)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(243)
    plt.axis('off')
    plt.imshow(img3)
    plt.subplot(244)
    plt.axis('off')
    plt.imshow(img4)
    plt.subplot(245)
    plt.axis('off')
    plt.imshow(img5)
    plt.subplot(246)
    plt.axis('off')
    plt.imshow(img6)
    plt.show()
def plot07(img1,img2,img3,img4,img5,img6,img7):
    plt.figure(figsize=(35,17)) #//
    plt.subplot(241)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(242)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(243)
    plt.axis('off')
    plt.imshow(img3)
    plt.subplot(244)
    plt.axis('off')
    plt.imshow(img4)
    plt.subplot(245)
    plt.axis('off')
    plt.imshow(img5)
    plt.subplot(246)
    plt.axis('off')
    plt.imshow(img6)
    plt.subplot(247)
    plt.axis('off')
    plt.imshow(img7)
    plt.show()
def plot08(img1,img2,img3,img4,img5,img6,img7,img8):
    plt.figure(figsize=(35,17))  #//
    plt.subplot(241)
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(242)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(243)
    plt.axis('off')
    plt.imshow(img3)
    plt.subplot(244)
    plt.axis('off')
    plt.imshow(img4)
    plt.subplot(245)
    plt.axis('off')
    plt.imshow(img5)
    plt.subplot(246)
    plt.axis('off')
    plt.imshow(img6)
    plt.subplot(247)
    plt.axis('off')
    plt.imshow(img7)
    plt.subplot(248)
    plt.axis('off')
    plt.imshow(img8)
    plt.show()
def plot09(img1,img2,img3,img4,img5,img6,img7,img8,img9):
    plt.figure(figsize=(42,16)) #//
    plt.subplot(251) 
    plt.axis('off')
    plt.imshow(img1)
    plt.subplot(252)
    plt.axis('off')
    plt.imshow(img2)
    plt.subplot(253)
    plt.axis('off')
    plt.imshow(img3)
    plt.subplot(254)
    plt.axis('off')
    plt.imshow(img4)
    plt.subplot(255)
    plt.axis('off')
    plt.imshow(img5)
    plt.subplot(256)
    plt.axis('off')
    plt.imshow(img6)
    plt.subplot(257)
    plt.axis('off')
    plt.imshow(img7)
    plt.subplot(258)
    plt.axis('off')
    plt.imshow(img8)
    plt.subplot(259)
    plt.axis('off')
    plt.imshow(img9)
    plt.plot()